@@ -177,6 +177,18 @@ def _print(y, x, *args):
     for arg in args:
         if isinstance(arg, int):
             mode = pal[arg][2] | curses.color_pair(arg)
+        elif isinstance(arg, tuple):
+            # this is a single line with formatting, so no word wrapping
+            _x = x
+            for a in arg:
+                if isinstance(a, int):
+                    mode = pal[a][2] | curses.color_pair(a)
+                else:
+                    a = strip_ansi(str(a))
+                    addstr(_y, _x, a, mode)
+                    _x += len(a)
+            _y += 1
+            _x = x
         else:
             arg = str(arg)
             lines = arg.split("\n")
@@ -417,6 +429,8 @@ def draw_warnings(y, warnings):
 
 
 def draw_result_details(y, detail_panel_scroll_top, root, zest_result):
+    log(f"IN draw_result_details {detail_panel_scroll_top=}")
+
     if zest_result is None:
         return y
 
@@ -465,21 +479,21 @@ def draw_result_details(y, detail_panel_scroll_top, root, zest_result):
         y += 1
     else:
         formatted = zest_result.error_formatted
-        lines = []
-        for line in formatted:
-            lines += [sub_line for sub_line in line.strip().split("\n")]
 
-        s = [
-            PAL_NONE,
-            "raised: ",
-            PAL_ERROR_MESSAGE,
-            _up_to_first_space(zest_result.error),
-        ]
-        _print(y, 0, *s)
-        y += 1
+        # Render all of the details lines list
+        # Some of those lines will be tuples when we want _print to
+        # render with formatting otherwise they will be strings
+        # when the _print is stripping out escape characters
+
+        lines = []
+
+        formatted_split_lines = []
+        for line in formatted:
+            formatted_split_lines += [sub_line for sub_line in line.strip().split("\n")]
 
         is_libs = False
-        for line in lines[detail_panel_scroll_top:-1]:
+        for line in formatted_split_lines:
+            # s is a single line with formatting
             s = []
             split_line = traceback_match_filename(root, line)
             if split_line is None:
@@ -508,31 +522,35 @@ def draw_result_details(y, detail_panel_scroll_top, root, zest_result):
                         PAL_ERROR_BASE,
                         " in function ",
                     ]
-                    s += [PAL_ERROR_MESSAGE, context]
-            _print(y, 2, *s)
-            y += 1
+                    s += [(PAL_ERROR_MESSAGE, context)]
+
+            lines += [tuple(s)]
 
         error_message = str(zest_result.error).strip()
         if error_message != "":
-            _print(y, 2, PAL_ERROR_MESSAGE, error_message)
+            lines += [(PAL_ERROR_MESSAGE, error_message)]
 
-        y += 2
         if zest_result.stdout is not None and zest_result.stdout != "":
-            y += 2
-            y, _ = _print(y, 0, PAL_NONE, "Stdout:")
-            y, _ = _print(y, 0, PAL_STDOUT, "".join(zest_result.stdout))
-            y += 1
+            lines += [(PAL_NONE, "\n")]
+            lines += [(PAL_NONE, "Stdout:")]
+            for l in zest_result.stdout.split("\n"):
+                lines += [(PAL_STDOUT, l)]
 
         if zest_result.stderr is not None and zest_result.stderr != "":
-            y += 2
-            y, _ = _print(y, 0, PAL_NONE, "Stderr:")
-            y, _ = _print(y, 0, PAL_STDOUT, "".join(zest_result.stderr))
-            y += 1
+            lines += [(PAL_NONE, "\n")]
+            lines += [(PAL_NONE, "Stderr:")]
+            for l in zest_result.stderr.split("\n"):
+                lines += [(PAL_STDERR, l)]
 
         if zest_result.logs is not None and zest_result.logs != "":
-            y += 2
-            y, _ = _print(y, 0, PAL_NONE, "Logs:")
-            y, _ = _print(y, 0, PAL_STDOUT, "".join(zest_result.logs))
+            lines += [(PAL_NONE, "\n")]
+            lines += [(PAL_NONE, "Logs:")]
+            for l in zest_result.logs.split("\n"):
+                lines += [(PAL_STDERR, l)]
+
+        # RENDER those lines starting at scroll offset
+        for line in lines[detail_panel_scroll_top:-1]:
+            _print(y, 0, line)
             y += 1
 
     return y
@@ -569,6 +587,7 @@ def _run(
     run_state = STOPPED
     warnings = []
     runner = None
+    failed_to_run = []
     debug_mode = kwargs.get("debug_mode", False)
     request_run = None
     request_stop = False  # Stop the current run
@@ -632,16 +651,31 @@ def _run(
             scr_w = curses.COLS
             h = 7
             w = 40
-            y = 10
+            y = 11
             x = (scr_w - w) // 2
             win2 = scr.subwin(h, w, y, x)
             win2.clear()
 
+            n_failed_to_run = len(failed_to_run)
             if n_allowed_to_run != n_run:
+                assert n_failed_to_run == n_allowed_to_run - n_run
+                h = n_failed_to_run + 7
+                w = 80
+                y = 11
+                x = (scr_w - w) // 2
+                win2 = scr.subwin(h, w, y, x)
+                win2.clear()
+
                 win2.attrset(curses.color_pair(PAL_ERROR_BOX))
                 win2.box()
+
                 msg = f"WARNING! {n_allowed_to_run-n_run} failed to run."
-                win2.addstr(h // 2, (w - len(msg)) // 2, msg, curses.color_pair(PAL_ERROR_BOX))
+                win2.addstr(2, (w - len(msg)) // 2, msg, curses.color_pair(PAL_ERROR_BOX))
+
+                for i, fail in enumerate(failed_to_run):
+                    msg = fail
+                    win2.addstr(4 + i, 4, msg, curses.color_pair(PAL_ERROR_BOX))
+
                 win2.bkgd(' ', curses.color_pair(PAL_ERROR_BOX))
             elif n_errors == 0:
                 win2.attrset(curses.color_pair(PAL_SUCCESS_BOX))
@@ -724,7 +758,7 @@ def _run(
 
         nonlocal request_run, request_stop, runner
         nonlocal zest_results_by_full_name
-        nonlocal n_allowed_to_run
+        nonlocal n_allowed_to_run, failed_to_run
         if run_state == STOPPED:
             # Tests are done. The runner_thread should be stopped
             # Ways out:
@@ -749,10 +783,6 @@ def _run(
             running = runner.poll(request_stop)
             time.sleep(0.05)
 
-            if not running and not request_end:
-                nonlocal show_result_box
-                show_result_box = True
-
             if not running or request_stop or request_run is not None:
                 new_state(STOPPING)
 
@@ -762,11 +792,26 @@ def _run(
             #   * The runner has terminated. Goto STOPPED
             running = runner.poll(True)
             if not running:
+                ran_names = {
+                    result.full_name
+                    for result in runner.results
+                }
+                failed_to_run = [
+                    name
+                    for name in runner.allow_to_run
+                    if name not in ran_names
+                ]
+
                 n_allowed_to_run = len(runner.allow_to_run)
                 runner = None
                 new_state(STOPPED)
                 zest_results_by_full_name = load_results(zest_results_path)
 
+            if not request_end:
+                nonlocal show_result_box
+                show_result_box = True
+
+
         # elif run_state == WATCHING:
         #     if watch_timestamp != os.path.getmtime(watch_file):
         #         request_run = ".".join(request_watch[2])
@@ -796,6 +841,8 @@ def _run(
             if _kbhit():
                 key = scr.getkey()
 
+                log(f"{key=}")
+
                 if show_result_box:
                     # Any key to exit box
                     show_result_box = False
@@ -864,14 +911,31 @@ def _run(
                 #     show_result_box = not show_result_box
                 #     dirty = True
 
+                # TODO Set this correctly
+                page_size = 20
+
                 if key == "KEY_DOWN":
                     detail_panel_scroll_top += 1
                     dirty = True
 
                 if key == "KEY_UP":
-                    detail_panel_scroll_top = max(0, detail_panel_scroll_top - 1)
+                    detail_panel_scroll_top -= 1
                     dirty = True
 
+                if key == "KEY_NPAGE":
+                    # Page down
+                    detail_panel_scroll_top += page_size
+                    dirty = True
+
+                if key == "KEY_PPAGE":
+                    detail_panel_scroll_top -= page_size
+                    dirty = True
+
+                # BOUND scroll
+                # TODO: Defer this in render time?
+                # detail_panel_scroll_top = max(0, detail_panel_scroll_top - 1)
+
+
                 if key == "n":
                     fails_panel_page += 1
                     dirty = True
